powered by
Plots the Variable Importance in Projections (VIP) indexes of a PLS regression.
plo_vip(object, ncomp = NULL, sort = FALSE, col = "steelblue4", repel = FALSE)
a ggplot2 object
ggplot2
an object of class mvr from pls package
mvr
pls
the number of components to use for computing VIPs
logical. If TRUE, bars are sorted by decreasing VIPs. Default is FALSE.
TRUE
FALSE
color of the bars
logical. If TRUE, the names of the variables are repelled with geom_text_repel. Default is FALSE
geom_text_repel
Nicolas Robette
Martens, H., Næs, T. (1989) Multivariate calibration. Chichester: Wiley.
Tenenhaus, M. (1998) La Regression PLS. Theorie et Pratique. Editions TECHNIP, Paris.
VIP
library(pls) data(yarn) pls <- mvr(density ~ NIR, ncomp = 5, data = yarn, validation = "CV", method = "oscorespls") plo_vip(pls)
Run the code above in your browser using DataLab